@@ -20,4 +20,7 @@ class BleError(Enum):
     ENCRYPTION_VALIDATION_FAILED      = "ENCRYPTION_VALIDATION_FAILED"
     SETUP_FAILED                      = "SETUP_FAILED"
     NOT_IN_RECOVERY_MODE              = "NOT_IN_RECOVERY_MODE"
-    RECOVERY_MODE_DISABLED            = "RECOVERY_MODE_DISABLED"
\ No newline at end of file
+    RECOVERY_MODE_DISABLED            = "RECOVERY_MODE_DISABLED"
+
+    NO_SCANS_RECEIVED                 = "NO_SCANS_RECEIVED"
+    DIFFERENT_MODE_THAN_REQUIRED      = "DIFFERENT_MODE_THAN_REQUIRED"
\ No newline at end of file
